Order-Revealing Encryption based on LWE from Seoul National University of Science and Technology.

Seoultech websit : https://en.seoultech.ac.kr

This ORE is based on LWE against to'Quantum Computer' with 'Shor algorithm'

Author : Jaehwan Park (Seoultech / now at University of Tennessee, Knoxville)